@@ -24,7 +24,7 @@
 #define __GS_WINDOW_H
 
 #include <gdk/gdk.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -81,8 +81,8 @@ void        gs_window_set_logout_timeout (GSWindow  *window,
                                           glong      timeout);
 void        gs_window_set_logout_command (GSWindow   *window,
                                           const char *command);
-void        gs_window_set_away_message   (GSWindow   *window,
-                                          const char *away_message);
+void        gs_window_set_status_message   (GSWindow   *window,
+                                            const char *status_message);
 
 void        gs_window_request_unlock     (GSWindow  *window);
 void        gs_window_cancel_unlock_request (GSWindow  *window);
@@ -93,8 +93,8 @@ GSWindow  * gs_window_new                (GdkScreen *screen,
 void        gs_window_show               (GSWindow  *window);
 void        gs_window_destroy            (GSWindow  *window);
 GdkWindow * gs_window_get_gdk_window     (GSWindow  *window);
+GtkWidget * gs_window_get_drawing_area   (GSWindow  *window);
 void        gs_window_clear              (GSWindow  *window);
-void        gs_window_clear_to_background_pixmap (GSWindow  *window);
 
 G_END_DECLS
 
