@@ -42,22 +42,31 @@ watcher_idle_cb (GSWatcher *watcher,
         return FALSE;
 }
 
+static gboolean
+watcher_idle_notice_cb (GSWatcher *watcher,
+                        gboolean   is_idle,
+                        gpointer   data)
+{
+        g_message ("Idle notice status changed: %s", is_idle ? "idle" : "not idle");
+
+        return TRUE;
+}
+
 static void
 connect_watcher_signals (GSWatcher *watcher)
 {
-        g_signal_connect (watcher, "idle_changed",
+        g_signal_connect (watcher, "idle-changed",
                           G_CALLBACK (watcher_idle_cb), NULL);
+        g_signal_connect (watcher, "idle-notice-changed",
+                          G_CALLBACK (watcher_idle_notice_cb), NULL);
 }
 
 static void
 test_watcher (void)
 {
         GSWatcher *watcher;
-        guint      timeout;
 
-        timeout = 60000;
-
-        watcher = gs_watcher_new (timeout);
+        watcher = gs_watcher_new ();
         gs_watcher_set_enabled (watcher, TRUE);
         gs_watcher_set_active (watcher, TRUE);
 
@@ -92,5 +101,5 @@ main (int    argc,
 
         gs_debug_shutdown ();
 
-	return 0;
+        return 0;
 }
